jQuery(document).ready(function($) {
    // Cache DOM elements right at the start
    const serviceForm = $('#ctrlbs-service-form');
    const serviceFormContainer = $('.ctrlbs-service-form');
    
    console.log('CTRLBS Admin script loaded.');

    // Delete service
    $(document).on('click', '.delete-service', function(e) {
        e.preventDefault();
        if (!confirm('Are you sure you want to delete this service?')) {
            return;
        }

        const row = $(this).closest('tr');
        const serviceId = $(this).data('id');

        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'ctrlbs_admin_action',
                admin_action: 'delete_service',
                service_id: serviceId,
                booking_nonce: ctrlbsNonce.nonce
            },
            success: function(response) {
                if (response.success) {
                    row.fadeOut(400, function() {
                        $(this).remove();
                    });
                    displayAdminMessage('success', response.data.message);
                } else {
                    displayAdminMessage('error', response.data.message);
                }
            },
            error: function(jqXHR, textStatus) {
                displayAdminMessage('error', 'AJAX error: ' + textStatus);
            }
        });
    });

    // Edit service
    $(document).on('click', '.edit-service', function(e) {
        e.preventDefault();
        const row = $(this).closest('tr');
        const serviceId = $(this).data('id');
        const serviceName = row.find('td:first').text().trim();
        const servicePrice = row.find('td:eq(1)').text().replace(/[^0-9.]/g, '');

        $('#service_id').val(serviceId);
        $('#service_name').val(serviceName);
        $('#service_price').val(servicePrice);
        serviceFormContainer.slideDown();
    });

    // Cancel/Delete booking
    $(document).on('click', '.cancel-booking', function(e) {
        e.preventDefault();
        const row = $(this).closest('tr');
        const isPast = row.closest('#past').length > 0;
        const confirmMessage = isPast 
            ? 'Are you sure you want to delete this booking?' 
            : 'Are you sure you want to cancel this booking?';

        if (!confirm(confirmMessage)) {
            return;
        }

        const bookingId = $(this).data('id');

        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'ctrlbs_admin_action', 
                admin_action: 'cancel_booking',
                booking_id: bookingId,
                booking_nonce: ctrlbsNonce.nonce
            },
            success: function(response) {
                if (response.success) {
                    row.fadeOut(400, function() {
                        $(this).remove();
                    });
                    displayAdminMessage('success', response.data.message);
                } else {
                    displayAdminMessage('error', response.data.message);
                }
            },
            error: function(jqXHR, textStatus) {
                displayAdminMessage('error', 'AJAX error: ' + textStatus);
            }
        });
    });
        
    // Add new service button
    $('#add-service').on('click', function(e) {
        e.preventDefault();
        serviceForm[0].reset();
        $('#service_id').val('');
        serviceFormContainer.slideDown();
    });

    // Cancel service form
    $('.cancel-service').on('click', function(e) {
        e.preventDefault();
        serviceForm[0].reset();
        $('#service_id').val('');
        serviceFormContainer.slideUp();
    });

    // Service form submission (Add/Edit)
    serviceForm.on('submit', function(e) {
        e.preventDefault();
        const formData = new FormData(this);
        const serviceId = $('#service_id').val();

        formData.append('action', 'ctrlbs_admin_action');
        formData.append('admin_action', serviceId ? 'update_service' : 'add_service');
        formData.append('booking_nonce', ctrlbsNonce.nonce);

        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            success: function(response) {
                if (response.success) {
                    window.location.reload();
                } else {
                    displayAdminMessage('error', response.data.message);
                }
            },
            error: function(jqXHR, textStatus) {
                displayAdminMessage('error', 'AJAX error: ' + textStatus);
            }
        });
    });

    // Tab switching functionality
    $(document).on('click', '.nav-tab', function(e) {
        e.preventDefault();
        $('.nav-tab').removeClass('nav-tab-active');
        $(this).addClass('nav-tab-active');
        $('.ctrlbs-tab-content').removeClass('active').hide();
        $($(this).attr('href')).addClass('active').show();
    });

    // Helper function for displaying admin messages
    function displayAdminMessage(type, message) {
        const notice = $('<div>')
            .addClass(`notice notice-${type} is-dismissible`)
            .append($('<p>').text(message));
        $('.wrap h1').after(notice);
        setTimeout(() => {
            notice.fadeOut(400, function() {
                $(this).remove();
            });
        }, 3000);
    }
});