<?php
declare(strict_types=1);

if (!defined('ABSPATH')) {
    exit;
}

if (!defined('CTRLBS_VERSION')) {
    define('CTRLBS_VERSION', '1.0.0');
}

function ctrlbs_add_admin_menu(): void {
    add_menu_page(
        'Booking System',
        'Booking System',
        'manage_options',
        'ctrlbs-system',
        'ctrlbs_render_admin_dashboard',
        'dashicons-calendar-alt',
        20
    );

    add_submenu_page(
        'ctrlbs-system',
        'Dashboard',
        'Dashboard',
        'manage_options',
        'ctrlbs-system',
        'ctrlbs_render_admin_dashboard'
    );

    add_submenu_page(
        'ctrlbs-system',
        'Services',
        'Services',
        'manage_options',
        'ctrlbs-system-services',
        'ctrlbs_render_services_page'
    );

    add_submenu_page(
        'ctrlbs-system',
        'Booking Stats',
        'Stats',
        'manage_options',
        'ctrlbs-system-stats',
        'ctrlbs_render_stats_page'
    );

    add_submenu_page(
        'ctrlbs-system',
        'Settings',
        'Settings',
        'manage_options',
        'ctrlbs-system-settings',
        'ctrlbs_render_settings_page'
    );
}
add_action('admin_menu', 'ctrlbs_add_admin_menu');

/**
 * Handle settings form submission
 */
add_action('admin_post_save_ctrlbs_settings', function () {
    $nonce = isset($_POST['ctrlbs_nonce'])
      ? sanitize_text_field(wp_unslash($_POST['ctrlbs_nonce']))
      : '';
  
    if (empty($nonce) || !wp_verify_nonce($nonce, 'save_ctrlbs_settings')) {
      wp_die('Invalid nonce');
    }
  
    if (isset($_POST['ctrlbs_settings']) && is_array($_POST['ctrlbs_settings'])) {
        // First sanitizes the raw POST data
        $sanitized_input = map_deep($_POST['ctrlbs_settings'], 'sanitize_text_field');
        // Then unslashes the sanitized data
        $unslashed_input = wp_unslash($sanitized_input);
        // Finally runs through settings sanitizer
        $sanitized_settings = ctrlbs_sanitize_settings($unslashed_input);
        ctrlbs_update_settings($sanitized_settings);
    }
    wp_redirect(admin_url('admin.php?page=ctrlbs-system-settings&updated=true'));
    exit;
});

/**
 * Render admin pages
 */
function ctrlbs_render_admin_dashboard(): void {
    require_once CTRLBS_PLUGIN_DIR . 'templates/admin/dashboard.php';
}

function ctrlbs_render_services_page(): void {
    require_once CTRLBS_PLUGIN_DIR . 'templates/admin/services.php';
}

function ctrlbs_render_stats_page(): void {
    require_once CTRLBS_PLUGIN_DIR . 'templates/admin/stats.php';
}

function ctrlbs_render_settings_page(): void {
    require_once CTRLBS_PLUGIN_DIR . 'templates/admin/settings.php';
}