<?php
declare(strict_types=1);

if (!defined('ABSPATH')) {
    exit;
}

function ctrlbs_create_booking(array $booking_data): int|false {
    global $wpdb;
    
    $result = $wpdb->insert(
        $wpdb->prefix . 'ctrlbs_bookings',
        [
            'name' => $booking_data['name'],
            'email' => $booking_data['email'],
            'phone' => $booking_data['phone'],
            'service_id' => $booking_data['service_id'],
            'booking_date' => $booking_data['date'],
            'booking_time' => $booking_data['time'],
            'created_at' => current_time('mysql')
        ],
        ['%s', '%s', '%s', '%d', '%s', '%s', '%s'] 
    );

    return $result ? $wpdb->insert_id : false;
}

function ctrlbs_get_booking(int $id): ?object {
    global $wpdb;
    return $wpdb->get_row($wpdb->prepare(
        "SELECT b.*, s.name as service_name, s.price as service_price 
         FROM {$wpdb->prefix}ctrlbs_bookings b 
         LEFT JOIN {$wpdb->prefix}ctrlbs_services s ON b.service_id = s.id 
         WHERE b.id = %d",
        $id
    ));
}

function ctrlbs_get_bookings_by_email(string $email): array {
    global $wpdb;
    return $wpdb->get_results($wpdb->prepare(
        "SELECT b.*, s.name as service_name, s.price as service_price 
         FROM {$wpdb->prefix}ctrlbs_bookings b 
         LEFT JOIN {$wpdb->prefix}ctrlbs_services s ON b.service_id = s.id 
         WHERE b.email = %s 
         ORDER BY b.booking_date DESC, b.booking_time DESC",
        $email
    )) ?: [];
}

function ctrlbs_delete_booking(int $id): bool {
    global $wpdb;
    return (bool)$wpdb->delete(
        $wpdb->prefix . 'ctrlbs_bookings',
        ['id' => $id],
        ['%d']
    );
}

function ctrlbs_get_bookings_by_month(int $year): array {
    global $wpdb;
    return $wpdb->get_results($wpdb->prepare(
        "SELECT MONTH(booking_date) as month,
         COUNT(*) as count,
         DATE_FORMAT(booking_date, '%%M') as month_name
         FROM {$wpdb->prefix}ctrlbs_bookings
         WHERE YEAR(booking_date) = %d
         GROUP BY MONTH(booking_date)
         ORDER BY month ASC",
        $year
    ), ARRAY_A) ?: [];
}

function ctrlbs_get_bookings_by_service(): array {
    global $wpdb;
    return $wpdb->get_results(
        "SELECT s.name as service_name, 
         COUNT(b.id) as booking_count
         FROM {$wpdb->prefix}ctrlbs_services s
         LEFT JOIN {$wpdb->prefix}ctrlbs_bookings b ON s.id = b.service_id
         GROUP BY s.id, s.name
         ORDER BY booking_count DESC",
        ARRAY_A
    ) ?: [];
}

function ctrlbs_get_upcoming_bookings(): array {
    global $wpdb;
    $current_time = current_time('H:i');
    $current_date = current_time('Y-m-d');
    
    return $wpdb->get_results($wpdb->prepare(
        "SELECT b.*, s.name as service_name, s.price as service_price 
        FROM {$wpdb->prefix}ctrlbs_bookings b 
        LEFT JOIN {$wpdb->prefix}ctrlbs_services s ON b.service_id = s.id 
         WHERE (b.booking_date > %s) 
         OR (b.booking_date = %s AND b.booking_time > %s)
         ORDER BY b.booking_date ASC, b.booking_time ASC",
        $current_date,
        $current_date,
        $current_time
    )) ?: [];
}

function ctrlbs_get_past_bookings(): array {
    global $wpdb;
    $current_time = current_time('H:i');
    $current_date = current_time('Y-m-d');
    
    return $wpdb->get_results($wpdb->prepare(
        "SELECT b.*, s.name as service_name, s.price as service_price 
         FROM {$wpdb->prefix}ctrlbs_bookings b 
         LEFT JOIN {$wpdb->prefix}ctrlbs_services s ON b.service_id = s.id 
         WHERE (b.booking_date < %s) 
         OR (b.booking_date = %s AND b.booking_time <= %s)
         ORDER BY b.booking_date DESC, b.booking_time DESC",
        $current_date,
        $current_date,
        $current_time
    )) ?: [];
}
