<?php
declare(strict_types=1);

if (!defined('ABSPATH')) {
    exit;
}

class CTRLBS_Elementor_Widget extends \Elementor\Widget_Base {
    public function get_name(): string {
        return 'ctrlbs_booking_form';
    }

    public function get_title(): string {
        return esc_html__('Booking Form', 'ctrl-booking-system');
    }

    public function get_icon(): string {
        return 'eicon-form-horizontal';
    }

    public function get_categories(): array {
        return ['general'];
    }

    protected function register_controls(): void {
        // Content Section
        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'ctrl-booking-system'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'form_title',
            [
                'label' => esc_html__('Form Title', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Book an Appointment', 'ctrl-booking-system'),
            ]
        );

        $this->end_controls_section();

        // Style Section
        $this->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'ctrl-booking-system'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        // Title Typography
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => esc_html__('Title Typography', 'ctrl-booking-system'),
                'selector' => esc_attr('{{WRAPPER}} .ctrlbs-form-widget h2'),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Title Color', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#333333'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget h2') => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label' => esc_html__('Form Background', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#ffffff'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget') => 'background-color: {{VALUE}} !important;',
                ],
            ]
        );

        // Form Border
        $this->add_control(
            'form_border_width',
            [
                'label' => esc_html__('Form Border Width', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget') => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'default' => [
                    'top' => '1',
                    'right' => '1',
                    'bottom' => '1',
                    'left' => '1',
                    'unit' => esc_attr('px'),
                ],
            ]
        );

        $this->add_control(
            'form_border_color',
            [
                'label' => esc_html__('Form Border Color', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#cccccc'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget') => 'border-color: {{VALUE}} !important; border-style: solid !important;',
                ],
            ]
        );

        // Form Padding
        $this->add_responsive_control(
            'form_padding',
            [
                'label' => esc_html__('Form Padding', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget') => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'default' => [
                    'top' => '20',
                    'right' => '20',
                    'bottom' => '20',
                    'left' => '20',
                    'unit' => esc_attr('px'),
                ],
            ]
        );

        // Form Border Radius
        $this->add_control(
            'form_border_radius',
            [
                'label' => esc_html__('Form Border Radius', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget') => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'default' => [
                    'top' => '8',
                    'right' => '8',
                    'bottom' => '8',
                    'left' => '8',
                    'unit' => esc_attr('px'),
                ],
            ]
        );

        // Labels Style
        $this->add_control(
            'labels_heading',
            [
                'label' => esc_html__('Labels', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'label_color',
            [
                'label' => esc_html__('Label Color', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#333333'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget label') => 'color: {{VALUE}} !important;',
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget .ctrlbs-validation-message:not(.error)') => 'color: {{VALUE}} !important;',
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget .ctrlbs-validation-message.error') => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'label_typography',
                'label' => esc_html__('Label Typography', 'ctrl-booking-system'),
                'selector' => esc_attr('{{WRAPPER}} .ctrlbs-form-widget label'),
            ]
        );

        // Input Fields Style
        $this->add_control(
            'input_heading',
            [
                'label' => esc_html__('Input Fields', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'input_background',
            [
                'label' => esc_html__('Input Background', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#ffffff'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget input, {{WRAPPER}} .ctrlbs-form-widget select') => 'background-color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'input_text_color',
            [
                'label' => esc_html__('Input Text Color', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#333333'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget input, {{WRAPPER}} .ctrlbs-form-widget select') => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'input_border_color',
            [
                'label' => esc_html__('Input Border Color', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#cccccc'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget input, {{WRAPPER}} .ctrlbs-form-widget select') => 'border-color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'input_focus_border_color',
            [
                'label' => esc_html__('Input Focus Border Color', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#007cba'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget input:focus, {{WRAPPER}} .ctrlbs-form-widget select:focus') => 'border-color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'input_border_radius',
            [
                'label' => esc_html__('Input Fields Border Radius', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget input, {{WRAPPER}} .ctrlbs-form-widget select') => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'default' => [
                    'top' => '4',
                    'right' => '4',
                    'bottom' => '4',
                    'left' => '4',
                    'unit' => esc_attr('px'),
                ],
            ]
        );

        // Button Style
        $this->add_control(
            'button_heading',
            [
                'label' => esc_html__('Submit Button', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'button_background',
            [
                'label' => esc_html__('Button Background', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#007cba'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget button') => 'background-color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover',
            [
                'label' => esc_html__('Button Hover Background', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#006ba1'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget button:hover') => 'background-color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'button_text_color',
            [
                'label' => esc_html__('Button Text Color', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => esc_attr('#ffffff'),
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget button') => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'button_margin_top',
            [
                'label' => esc_html__('Button Top Spacing', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', 'em'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 10,
                        'step' => 0.1,
                    ],
                ],
                'default' => [
                    'unit' => esc_attr('px'),
                    'size' => 20,
                ],
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget button') => 'margin-top: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_control(
            'button_border_radius',
            [
                'label' => esc_html__('Button Border Radius', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget button') => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'default' => [
                    'top' => '4',
                    'right' => '4',
                    'bottom' => '4',
                    'left' => '4',
                    'unit' => esc_attr('px'),
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'button_typography',
                'label' => esc_html__('Button Typography', 'ctrl-booking-system'),
                'selector' => esc_attr('{{WRAPPER}} .ctrlbs-form-widget button'),
            ]
        );

        $this->add_control(
            'button_padding',
            [
                'label' => esc_html__('Button Padding', 'ctrl-booking-system'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    esc_attr('{{WRAPPER}} .ctrlbs-form-widget button') => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );



        $this->end_controls_section();
    }


    protected function get_inline_styles(): string {
        $settings = $this->get_settings_for_display();
        $widget_id = $this->get_id();
        
        return "
            #elementor .elementor-element.elementor-element-{$widget_id} .ctrlbs-form-widget {
                transition: all .3s;
                --label-color: " . esc_attr($settings['label_color']) . ";
            }
    
            .ctrlbs-form-widget .ctrlbs-validation-message,
            .ctrlbs-form-widget .ctrlbs-success-message,
            .ctrlbs-form-widget .ctrlbs-error-message {
                color: " . esc_attr($settings['label_color']) . ";
            }
    
            .ctrlbs-form-widget input[type=\"date\"]::-webkit-datetime-edit-month-field,
            .ctrlbs-form-widget input[type=\"date\"]::-webkit-datetime-edit-year-field,
            .ctrlbs-form-widget input[type=\"date\"]::-webkit-datetime-edit-day-field {
                color: " . esc_attr($settings['input_text_color']) . ";
            }
    
            .ctrlbs-form-widget input[type=\"date\"]::-webkit-calendar-picker-indicator {
                filter: invert(" . ($settings['input_text_color'] === '#ffffff' ? '1' : '0') . ");
            }
        ";
    }


    protected function render(): void {
        wp_add_inline_style('ctrlbs-elementor', $this->get_inline_styles());

        
        $settings = $this->get_settings_for_display();
        ?>


        <div class="ctrlbs-form-widget">
            <h2><?php echo esc_html($settings['form_title']); ?></h2>
            <form id="ctrlbs-booking-form" class="ctrlbs-form">
                <?php wp_nonce_field('ctrlbs_nonce', 'booking_nonce'); ?>
                <div class="ctrlbs-field-group">
                    <label for="ctrlbs-name"><?php esc_html_e('Name:', 'ctrl-booking-system'); ?></label>
                    <input type="text" id="ctrlbs-name" name="name" required maxlength="50">
                </div>
                <div class="ctrlbs-field-group">
                    <label for="ctrlbs-phone"><?php esc_html_e('Phone:', 'ctrl-booking-system'); ?></label>
                    <input type="tel" id="ctrlbs-phone" name="phone" required pattern="[0-9\+\-\(\)\s]+" maxlength="20"
                        title="<?php echo esc_attr__('Please enter a valid phone number', 'ctrl-booking-system'); ?>">
                </div>
                <div class="ctrlbs-field-group">
                    <label for="ctrlbs-email"><?php esc_html_e('Email:', 'ctrl-booking-system'); ?></label>
                    <input type="email" id="ctrlbs-email" name="email" required maxlength="100">     
                </div>

                <div class="ctrlbs-field-group">
                    <label for="ctrlbs-service-select"><?php esc_html_e('Select Service:', 'ctrl-booking-system'); ?></label>
                    <select id="ctrlbs-service-select" name="service_id" required>
                        <option value=""><?php esc_html_e('Loading services...', 'ctrl-booking-system'); ?></option>
                    </select>
                </div>

                <div class="ctrlbs-field-group">
                    <label for="ctrlbs-booking-date"><?php esc_html_e('Select Date:', 'ctrl-booking-system'); ?></label>
                    <input type="date" 
                           id="ctrlbs-booking-date" 
                           name="date" 
                           required 
                           min="<?php echo esc_attr(gmdate('Y-m-d')); ?>">
                </div>

                <div class="ctrlbs-field-group">
                    <label for="ctrlbs-booking-time"><?php esc_html_e('Select Time:', 'ctrl-booking-system'); ?></label>
                    <select id="ctrlbs-booking-time" name="time" required>
                        <option value=""><?php esc_html_e('Select a date first', 'ctrl-booking-system'); ?></option>
                    </select>
                </div>

                <button type="submit" class="ctrlbs-submit"><?php esc_html_e('Book Now', 'ctrl-booking-system'); ?></button>
            </form>
            <div class="ctrlbs-success-message" style="display:none; margin-top: 10px;"></div>
            <div class="ctrlbs-error-message" style="display:none; margin-top: 10px;"></div>
        </div>
        <?php
    }
}