<?php
declare(strict_types=1);

if (!defined('ABSPATH')) {
    exit;
}

function ctrlbs_send_confirmation_email(array $booking_data, int $booking_id): bool {
    try {
        add_action('phpmailer_init', function($phpmailer) use ($booking_data, $booking_id) {
            $settings = get_option('ctrlbs_settings', []);
            $security = CTRLBS_Security::get_instance();

            // Configure SMTP
            $phpmailer->isSMTP();
            $phpmailer->Host = $settings['smtp_host'] ?? '';
            $phpmailer->SMTPAuth = true;
            $phpmailer->Username = $security->decrypt_value($settings['smtp_username'] ?? '');
            $phpmailer->Password = $security->decrypt_value($settings['smtp_password'] ?? '');
            $phpmailer->SMTPSecure = $settings['smtp_secure'] ?? 'tls';
            $phpmailer->Port = (int)($settings['smtp_port'] ?? 587);
            $phpmailer->CharSet = 'UTF-8';
        });

        // Setup email content
        $settings = get_option('ctrlbs_settings', []);
        $security = CTRLBS_Security::get_instance();
        $from_email = $security->decrypt_value($settings['smtp_username'] ?? get_option('admin_email'));
        $admin_email = $settings['admin_email'] ?? get_option('admin_email');

        $headers = [];
        $headers[] = 'Content-Type: text/html; charset=UTF-8';
        $headers[] = 'From: ' . get_bloginfo('name') . ' <' . $from_email . '>';
        if ($admin_email) {
            $headers[] = 'Bcc: ' . $admin_email;
        }

        $subject = sprintf(
            /* translators: %d: booking ID number */
            __('Booking Confirmation #%d', 'ctrl-booking-system'),
            $booking_id
        );

        $template_data = [
            'booking_id' => $booking_id,
            'name' => $booking_data['name'],
            'phone' => $booking_data['phone'],
            'email' => $booking_data['email'],
            'date' => $booking_data['date'],
            'time' => $booking_data['time'],
            'service_id' => $booking_data['service_id']
        ];

        $message = ctrlbs_get_email_template('booking-confirmation', $template_data);

        // Send email using wp_mail()
        return wp_mail($booking_data['email'], $subject, $message, $headers);

    } catch (Exception $e) {
        return false;
    }
}

function ctrlbs_get_email_template(string $template, array $data): string {
    ob_start();
    $template_path = CTRLBS_PLUGIN_DIR . 'templates/email/' . $template . '.php';

    if (!file_exists($template_path)) {
        return '';
    }

    include $template_path;
    return ob_get_clean();
}