<?php
declare(strict_types=1);

if (!defined('ABSPATH')) {
    exit;
}

function ctrlbs_initialize_plugin(): void {
    // Create database tables
    ctrlbs_create_tables();
    
    // Initialize settings
    ctrlbs_initialize_settings();
    
    // Handle donation notice options
    delete_option('ctrlbs_donation_notice_shown');
    delete_option('ctrlbs_donation_notice_dismissed');
    add_option('ctrlbs_donation_notice_shown', 0);
}

function ctrlbs_create_tables(): void {
    global $wpdb;
    
    $services_table = $wpdb->prefix . 'ctrlbs_services';
    $bookings_table = $wpdb->prefix . 'ctrlbs_bookings';
    
    $charset_collate = $wpdb->get_charset_collate();
    
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    
    dbDelta(ctrlbs_get_services_table_schema($services_table, $charset_collate));
    dbDelta(ctrlbs_get_bookings_table_schema($bookings_table, $services_table, $charset_collate));
    
    ctrlbs_insert_default_services($services_table);
}

function ctrlbs_get_services_table_schema(string $table, string $charset_collate): string {
    return "CREATE TABLE IF NOT EXISTS {$table} (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        name varchar(255) NOT NULL,
        price decimal(10,2) NOT NULL,
        PRIMARY KEY (id)
    ) {$charset_collate};";
}

function ctrlbs_get_bookings_table_schema(string $bookings_table, string $services_table, string $charset_collate): string {
    return "CREATE TABLE IF NOT EXISTS {$bookings_table} (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        name varchar(255) NOT NULL,
        email varchar(255) NOT NULL,
        phone varchar(20) NOT NULL,
        service_id mediumint(9) NOT NULL, 
        booking_date date NOT NULL,
        booking_time time NOT NULL,
        created_at timestamp DEFAULT CURRENT_TIMESTAMP,
        PRIMARY KEY (id),
        FOREIGN KEY (service_id) REFERENCES {$services_table}(id) ON DELETE CASCADE
    ) {$charset_collate};";
}

function ctrlbs_insert_default_services(string $services_table): void {
    global $wpdb;
    
    $count = $wpdb->get_var(
        $wpdb->prepare(
            "SELECT COUNT(*) FROM %i",
            $services_table
        )
    );
    
    if ((int)$count === 0) {
        $wpdb->insert(
            $services_table,
            ['name' => 'Basic Service', 'price' => 50.00],
            ['%s', '%f']
        );
        
        $wpdb->insert(
            $services_table, 
            ['name' => 'Premium Service', 'price' => 100.00],
            ['%s', '%f']
        );
    }
}

function ctrlbs_initialize_settings(): void {
    $default_settings = [
        'ctrlbs_currency' => 'USD',
        'ctrlbs_start_time' => '09:00',
        'ctrlbs_end_time' => '17:00',
        'ctrlbs_slot_duration' => 30,
        'ctrlbs_smtp_host' => '',
        'ctrlbs_smtp_port' => '587',
        'ctrlbs_smtp_username' => '',
        'ctrlbs_smtp_password' => '',
        'ctrlbs_smtp_secure' => 'tls',
        'ctrlbs_admin_email' => get_option('admin_email')
    ];

    foreach ($default_settings as $option => $value) {
        if (get_option($option) === false) {
            update_option($option, $value);
        }
    }
}