<?php
if (!defined('ABSPATH')) {
    exit;
}

$upcoming_bookings = ctrlbs_get_upcoming_bookings();
$past_bookings = ctrlbs_get_past_bookings();
$last_shown = get_option('ctrlbs_donation_notice_shown', 0);
$should_show = (!$last_shown) || ((time() - (int)$last_shown) >= (14 * DAY_IN_SECONDS));

$total_bookings = count($upcoming_bookings);
$today_bookings = array_filter($upcoming_bookings, function($booking) {
    return $booking->booking_date === gmdate('Y-m-d');
});
$today_count = count($today_bookings);
?>

<div class="wrap ctrlbs-dashboard">
    <h1 class="wp-heading-inline"><?php esc_html_e('Booking System Dashboard', 'ctrl-booking-system'); ?></h1>

    <?php if ($should_show): ?>
        <div class="ctrlbs-donation-notice is-dismissible">
            <h3><?php esc_html_e('Enjoying the Booking System plugin? Please consider:', 'ctrl-booking-system'); ?></h3>
            <p>
                <a href="<?php echo esc_url('https://buymeacoffee.com/ctrld'); ?>" target="_blank" class="button button-primary">
                    <?php esc_html_e('Support us on Buy Me a Coffee', 'ctrl-booking-system'); ?>
                </a>
                <a href="<?php echo esc_url('https://uk.trustpilot.com/review/ctrldigital.tech'); ?>" target="_blank" class="button">
                    <?php esc_html_e('Rate us on Trustpilot', 'ctrl-booking-system'); ?>
                </a>
            </p>
            <p><?php echo esc_html__('We hope to launch our premium version in June 2025. We endeavour to offer free 1 year subscriptions to all those who donate to us and leave their email details. Additionally, we will send emails inviting you to suggest features direct to the developers that will allow us to better serve your business needs. Stay tuned for more updates and enhancements.', 'ctrl-booking-system'); ?></p>
        </div>
    <?php endif; ?>

    <div class="ctrlbs-stats-grid">
        <div class="ctrlbs-stat-card">
            <div class="ctrlbs-stat-number"><?php echo esc_html($today_count); ?></div>
            <div class="ctrlbs-stat-label"><?php esc_html_e('Today\'s Bookings', 'ctrl-booking-system'); ?></div>
        </div>
        <div class="ctrlbs-stat-card">
            <div class="ctrlbs-stat-number"><?php echo esc_html($total_bookings); ?></div>
            <div class="ctrlbs-stat-label"><?php esc_html_e('Upcoming Bookings', 'ctrl-booking-system'); ?></div>
        </div>
        <div class="ctrlbs-stat-card">
            <div class="ctrlbs-stat-number"><?php echo count(ctrlbs_get_all_services()); ?></div>
            <div class="ctrlbs-stat-label"><?php esc_html_e('Active Services', 'ctrl-booking-system'); ?></div>
        </div>
    </div>

    <div class="ctrlbs-bookings-wrap">
        <h2 class="nav-tab-wrapper">
            <a href="#upcoming" class="nav-tab nav-tab-active" id="upcoming-tab">
                <?php esc_html_e('Upcoming Bookings', 'ctrl-booking-system'); ?>
            </a>
            <a href="#past" class="nav-tab" id="past-tab">
                <?php esc_html_e('Past Bookings', 'ctrl-booking-system'); ?>
            </a>
        </h2>

        <div id="upcoming" class="ctrlbs-tab-content active">
            <?php if (!empty($upcoming_bookings)): ?>
                <table class="ctrlbs-bookings-table">
                    <thead>
                        <tr>
                            <th><?php esc_html_e('Customer', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Service', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Date & Time', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Status', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Actions', 'ctrl-booking-system'); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($upcoming_bookings as $booking): ?>
                            <tr>
                                <td>
                                    <strong><?php echo esc_html($booking->name); ?></strong><br>
                                    <small><?php echo esc_html($booking->email); ?></small><br>
                                    <small><?php echo esc_html($booking->phone); ?></small>
                                </td>
                                <td><?php echo esc_html($booking->service_name); ?></td>
                                <td>
                                    <?php 
                                    echo esc_html(ctrlbs_format_date($booking->booking_date)) . '<br>';
                                    echo '<small>' . esc_html(ctrlbs_format_time($booking->booking_time)) . '</small>';
                                    ?>
                                </td>
                                <td>
                                    <span class="ctrlbs-status ctrlbs-status-upcoming">
                                        <?php esc_html_e('Upcoming', 'ctrl-booking-system'); ?>
                                    </span>
                                </td>
                                <td class="action-buttons">
                                    <button class="ctrlbs-action-button ctrlbs-button-cancel cancel-booking" 
                                            data-id="<?php echo esc_attr($booking->id); ?>">
                                        <?php esc_html_e('Cancel', 'ctrl-booking-system'); ?>
                                    </button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php else: ?>
                <p><?php esc_html_e('No upcoming bookings.', 'ctrl-booking-system'); ?></p>
            <?php endif; ?>
        </div>

        <div id="past" class="ctrlbs-tab-content">
            <?php if (!empty($past_bookings)): ?>
                <table class="ctrlbs-bookings-table">
                    <thead>
                        <tr>
                            <th><?php esc_html_e('Customer', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Service', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Date & Time', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Status', 'ctrl-booking-system'); ?></th>
                            <th><?php esc_html_e('Actions', 'ctrl-booking-system'); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($past_bookings as $booking): ?>
                            <tr>
                                <td>
                                    <strong><?php echo esc_html($booking->name); ?></strong><br>
                                    <small><?php echo esc_html($booking->email); ?></small><br>
                                    <small><?php echo esc_html($booking->phone); ?></small>
                                </td>
                                <td><?php echo esc_html($booking->service_name); ?></td>
                                <td>
                                    <?php 
                                    echo esc_html(ctrlbs_format_date($booking->booking_date)) . '<br>';
                                    echo '<small>' . esc_html(ctrlbs_format_time($booking->booking_time)) . '</small>';
                                    ?>
                                </td>
                                <td>
                                    <span class="ctrlbs-status ctrlbs-status-past">
                                        <?php esc_html_e('Past', 'ctrl-booking-system'); ?>
                                    </span>
                                </td>
                                <td class="action-buttons">
                                    <button class="ctrlbs-action-button ctrlbs-button-cancel cancel-booking" 
                                            data-id="<?php echo esc_attr($booking->id); ?>">
                                        <span class="dashicons dashicons-trash"></span>
                                        <?php esc_html_e('Delete', 'ctrl-booking-system'); ?>
                                    </button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php else: ?>
                <p><?php esc_html_e('No past bookings.', 'ctrl-booking-system'); ?></p>
            <?php endif; ?>
        </div>
    </div>
</div>

