<?php
if (!defined('ABSPATH')) {
    exit;
}
?>

<div class="wrap ctrlbs-services">
    
    <h1 class="wp-heading-inline"><?php esc_html_e('Manage Services', 'ctrl-booking-system'); ?></h1>
    
    <div class="ctrlbs-service-stats">
        <div class="ctrlbs-stat-card">
            <div class="ctrlbs-stat-label"><?php esc_html_e('Total Services', 'ctrl-booking-system'); ?></div>
            <div class="ctrlbs-stat-number"><?php echo esc_html(count(ctrlbs_get_all_services())); ?></div>
            </div>
        <div class="ctrlbs-stat-card">
            <div class="ctrlbs-stat-label"><?php esc_html_e('Active Bookings', 'ctrl-booking-system'); ?></div>
            <div class="ctrlbs-stat-number"><?php echo esc_html(count(ctrlbs_get_upcoming_bookings())); ?></div>
            </div>
        <div class="ctrlbs-stat-card">
            <div class="ctrlbs-stat-label"><?php esc_html_e('Total Revenue', 'ctrl-booking-system'); ?></div>
            <div class="ctrlbs-stat-number"><?php 
                $services = ctrlbs_get_all_services();
                $total = array_reduce($services, function($carry, $service) {
                    return $carry + $service->price;
                }, 0);
                echo esc_html(ctrlbs_format_price($total));
            ?></div>
        </div>
    </div>

    <div class="ctrlbs-add-new-service">
        <button class="button button-primary" id="add-service">
            <span class="dashicons dashicons-plus" style="<?php echo esc_attr('vertical-align: middle;'); ?>"></span>
            <?php esc_html_e('Add New Service', 'ctrl-booking-system'); ?>
        </button>
    </div>
    
    <div class="ctrlbs-service-form" style="display: none;">
        <h2><?php esc_html_e('Service Details', 'ctrl-booking-system'); ?></h2>
        <form id="ctrlbs-service-form" method="post">
            <?php wp_nonce_field('ctrlbs_service_nonce', 'service_nonce'); ?>
            <input type="hidden" name="service_id" id="service_id" value="<?php echo esc_attr(''); ?>">
            
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="service_name"><?php esc_html_e('Service Name', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="text" id="service_name" name="service_name" class="regular-text" required>
                        <p class="description"><?php esc_html_e('Enter a descriptive name for the service', 'ctrl-booking-system'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="service_price"><?php esc_html_e('Price', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="number" id="service_price" name="service_price" class="regular-text" step="0.01" min="0" required>
                        <p class="description"><?php esc_html_e('Set the price for this service', 'ctrl-booking-system'); ?></p>
                    </td>
                </tr>
            </table>
            
            <div class="ctrlbs-submit-buttons" style="margin-top: 20px;">
                <button type="submit" class="button button-primary">
                    <?php esc_html_e('Save Service', 'ctrl-booking-system'); ?>
                </button>
                <button type="button" class="button cancel-service">
                    <?php esc_html_e('Cancel', 'ctrl-booking-system'); ?>
                </button>
            </div>
        </form>
    </div>

    <div class="ctrlbs-services-table">
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th style="width: 40%"><?php esc_html_e('Service Name', 'ctrl-booking-system'); ?></th>
                    <th style="width: 20%"><?php esc_html_e('Price', 'ctrl-booking-system'); ?></th>
                    <th style="width: 15%"><?php esc_html_e('Status', 'ctrl-booking-system'); ?></th>
                    <th style="width: 25%"><?php esc_html_e('Actions', 'ctrl-booking-system'); ?></th>
                </tr>
            </thead>
            <tbody>
                <?php
                $services = ctrlbs_get_all_services();
                foreach ($services as $service):
                ?>
                    <tr>
                        <td>
                            <strong><?php echo esc_html($service->name); ?></strong>
                        </td>
                        <td class="price-column">
                            <?php echo esc_html(ctrlbs_format_price($service->price)); ?>
                        </td>
                        <td>
                            <span class="ctrlbs-status ctrlbs-status-active">
                                <?php esc_html_e('Active', 'ctrl-booking-system'); ?>
                            </span>
                        </td>
                        <td class="ctrlbs-service-actions">
                            <button class="button edit-service" 
                                    data-id="<?php echo esc_attr($service->id); ?>"
                                    data-name="<?php echo esc_attr($service->name); ?>"
                                    data-price="<?php echo esc_attr($service->price); ?>">
                                <span class="dashicons dashicons-edit"></span>
                                <?php esc_html_e('Edit', 'ctrl-booking-system'); ?>
                            </button>
                            <button class="button button-link-delete delete-service" 
                                    data-id="<?php echo esc_attr($service->id); ?>">
                                <span class="dashicons dashicons-trash"></span>
                                <?php esc_html_e('Delete', 'ctrl-booking-system'); ?>
                            </button>
                        </td>
                    </tr>
                <?php endforeach; ?>
                <?php if (empty($services)): ?>
                    <tr>
                        <td colspan="4" style="text-align: center;">
                            <?php esc_html_e('No services found. Click "Add New Service" to create one.', 'ctrl-booking-system'); ?>
                        </td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</div>