<?php if (!defined('ABSPATH')) exit;

$settings = ctrlbs_get_settings();
$security = CTRLBS_Security::get_instance();

// Get decrypted values
$smtp_username = $security->decrypt_value($settings['smtp_username'] ?? '');
$smtp_password = $security->decrypt_value($settings['smtp_password'] ?? '');

// Verify nonce for settings update message
$show_update_message = isset($_GET['updated']) && 
    isset($_GET['_wpnonce']) && 
    wp_verify_nonce(sanitize_text_field(wp_unslash($_GET['_wpnonce'])), 'ctrlbs_settings_updated');
?>

<div class="wrap ctrlbs-settings">
    <h1><?php esc_html_e('Booking System Settings', 'ctrl-booking-system'); ?></h1>

    <?php if ($show_update_message): ?>
        <div class="notice notice-success">
            <p><?php esc_html_e('Settings saved successfully.', 'ctrl-booking-system'); ?></p>
        </div>
    <?php endif; ?>

    <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
        <?php wp_nonce_field('save_ctrlbs_settings', 'ctrlbs_nonce'); ?>
        <input type="hidden" name="action" value="save_ctrlbs_settings">

        <!-- Email Settings -->
        <div class="card">
            <h2><span class="dashicons dashicons-email-alt"></span> <?php esc_html_e('Email Settings', 'ctrl-booking-system'); ?></h2>
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="smtp_host"><?php esc_html_e('SMTP Host', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="text" id="smtp_host" name="ctrlbs_settings[smtp_host]" 
                               value="<?php echo esc_attr($settings['smtp_host'] ?? ''); ?>" class="regular-text">
                        <p class="description"><?php esc_html_e('e.g., smtp.gmail.com', 'ctrl-booking-system'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="smtp_port"><?php esc_html_e('SMTP Port', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="number" id="smtp_port" name="ctrlbs_settings[smtp_port]" 
                               value="<?php echo esc_attr($settings['smtp_port'] ?? '587'); ?>" class="small-text">
                        <p class="description"><?php esc_html_e('Common ports: 587 (TLS) or 465 (SSL)', 'ctrl-booking-system'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="smtp_username"><?php esc_html_e('SMTP Username', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="text" id="smtp_username" name="ctrlbs_settings[smtp_username]" 
                               value="<?php echo esc_attr($smtp_username); ?>" class="regular-text">
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="smtp_password"><?php esc_html_e('SMTP Password', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="password" id="smtp_password" name="ctrlbs_settings[smtp_password]" 
                               value="<?php echo esc_attr($smtp_password); ?>" class="regular-text">
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="smtp_secure"><?php esc_html_e('Encryption Type', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <select id="smtp_secure" name="ctrlbs_settings[smtp_secure]">
                            <option value="tls" <?php selected($settings['smtp_secure'] ?? 'tls', 'tls'); ?>>TLS</option>
                            <option value="ssl" <?php selected($settings['smtp_secure'] ?? 'tls', 'ssl'); ?>>SSL</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="admin_email"><?php esc_html_e('Admin Email (Optional)', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="email" id="admin_email" name="ctrlbs_settings[admin_email]" 
                               value="<?php echo esc_attr($settings['admin_email'] ?? get_option('admin_email')); ?>" 
                               class="regular-text">
                    </td>
                </tr>
            </table>
        </div>

        <!-- Business Settings -->
        <div class="card">
            <h2><span class="dashicons dashicons-store"></span> <?php esc_html_e('Business Settings', 'ctrl-booking-system'); ?></h2>
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="currency"><?php esc_html_e('Currency', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <select id="currency" name="ctrlbs_settings[currency]">
                            <option value="USD" <?php selected($settings['currency'] ?? 'USD', 'USD'); ?>>USD ($)</option>
                            <option value="EUR" <?php selected($settings['currency'] ?? 'USD', 'EUR'); ?>>EUR (€)</option>
                            <option value="GBP" <?php selected($settings['currency'] ?? 'USD', 'GBP'); ?>>GBP (£)</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="business_hours_start"><?php esc_html_e('Business Hours Start', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="time" id="business_hours_start" name="ctrlbs_settings[business_hours_start]" 
                               value="<?php echo esc_attr($settings['business_hours_start'] ?? '09:00'); ?>">
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="business_hours_end"><?php esc_html_e('Business Hours End', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="time" id="business_hours_end" name="ctrlbs_settings[business_hours_end]" 
                               value="<?php echo esc_attr($settings['business_hours_end'] ?? '17:00'); ?>">
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Business Days', 'ctrl-booking-system'); ?></th>
                    <td>
                        <?php
                        $days = [
                            'monday' => __('Monday', 'ctrl-booking-system'),
                            'tuesday' => __('Tuesday', 'ctrl-booking-system'),
                            'wednesday' => __('Wednesday', 'ctrl-booking-system'),
                            'thursday' => __('Thursday', 'ctrl-booking-system'),
                            'friday' => __('Friday', 'ctrl-booking-system'),
                            'saturday' => __('Saturday', 'ctrl-booking-system'),
                            'sunday' => __('Sunday', 'ctrl-booking-system')
                        ];
                        foreach ($days as $day_key => $day_label): 
                            $checked = !empty($settings['business_days'][$day_key]);
                        ?>
                            <label style="display: block; margin-bottom: 8px;">
                                <input type="checkbox" 
                                       name="ctrlbs_settings[business_days][<?php echo esc_attr($day_key); ?>]" 
                                       value="1"
                                       <?php checked($checked); ?>>
                                <?php echo esc_html($day_label); ?>
                            </label>
                        <?php endforeach; ?>
                        <p class="description"><?php esc_html_e('Select the days your business is open', 'ctrl-booking-system'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="slot_duration"><?php esc_html_e('Slot Duration', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <select id="slot_duration" name="ctrlbs_settings[slot_duration]">
                            <option value="30" <?php selected($settings['slot_duration'] ?? '60', '30'); ?>>30 minutes</option>
                            <option value="60" <?php selected($settings['slot_duration'] ?? '60', '60'); ?>>1 hour</option>
                            <option value="90" <?php selected($settings['slot_duration'] ?? '60', '90'); ?>>1.5 hours</option>
                            <option value="120" <?php selected($settings['slot_duration'] ?? '60', '120'); ?>>2 hours</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="max_bookings_per_slot"><?php esc_html_e('Maximum Bookings Per Time Slot', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="number" 
                               id="max_bookings_per_slot" 
                               name="ctrlbs_settings[max_bookings_per_slot]" 
                               value="<?php echo esc_attr($settings['max_bookings_per_slot'] ?? '1'); ?>"
                               min="1" 
                               max="50" 
                               class="small-text">
                        <p class="description">
                            <?php esc_html_e('How many concurrent bookings can be made for each time slot. Useful for multiple staff members or restaurant tables.', 'ctrl-booking-system'); ?>
                        </p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="max_advance_days"><?php esc_html_e('Maximum Advance Booking Days', 'ctrl-booking-system'); ?></label>
                    </th>
                    <td>
                        <input type="number" id="max_advance_days" name="ctrlbs_settings[max_advance_days]" 
                               value="<?php echo esc_attr($settings['max_advance_days'] ?? '30'); ?>" 
                               min="1" max="365" class="small-text">
                        <p class="description"><?php esc_html_e('How many days in advance customers can book.', 'ctrl-booking-system'); ?></p>
                    </td>
                </tr>
            </table>
        </div>

        <?php submit_button(); ?>
    </form>
</div>
