<?php
if (!defined('ABSPATH')) {
    exit;
}

$current_year = (int)gmdate('Y');
$bookings_by_month = ctrlbs_get_bookings_by_month($current_year);
$bookings_by_service = ctrlbs_get_bookings_by_service();
$total_bookings = array_sum(array_column($bookings_by_month, 'count'));
$max_count = !empty($bookings_by_month) ? max(array_column($bookings_by_month, 'count')) : 0;
?>

<div class="wrap ctrlbs-stats">
    <h1><?php esc_html_e('Booking Statistics', 'ctrl-booking-system'); ?></h1>

    <div class="ctrlbs-stats-summary">
        <h3><?php esc_html_e('Total Bookings This Year', 'ctrl-booking-system'); ?></h3>
        <div class="ctrlbs-stats-total"><?php echo esc_html($total_bookings); ?></div>
    </div>

    <div class="ctrlbs-stats-container">  
        <!-- Bar Chart -->
        <div class="ctrlbs-stats-box">
            <h2><?php esc_html_e('Monthly Bookings', 'ctrl-booking-system'); ?></h2>
            <div class="ctrlbs-bar-chart">
                <?php 
                if ($max_count > 0 && !empty($bookings_by_month)): 
                    foreach ($bookings_by_month as $month): 
                        $height = ($month['count'] / $max_count) * 100;
                ?>
                    <div class="ctrlbs-bar-column">
                        <div class="ctrlbs-bar-value"><?php echo esc_html($month['count']); ?></div>
                        <div class="ctrlbs-bar" style="height: <?php echo esc_attr($height); ?>%"></div>
                        <div class="ctrlbs-bar-label"><?php echo esc_html(substr($month['month_name'], 0, 3)); ?></div>
                    </div>
                <?php 
                    endforeach;
                else: 
                ?>
                    <div class="ctrlbs-no-data"><?php esc_html_e('No bookings available for this year.', 'ctrl-booking-system'); ?></div>
                <?php endif; ?>
            </div>
        </div>

        <!-- Pie Chart -->
        <div class="ctrlbs-stats-box">
            <h2><?php esc_html_e('Bookings by Service', 'ctrl-booking-system'); ?></h2>
            <?php 
            $total = array_sum(array_column($bookings_by_service, 'booking_count'));
            $colors = ['#2271b1', '#d63638', '#00a32a', '#8c5e58', '#4f94d4', '#72aee6'];
            $gradient = '';
            $total_rotation = 0;

            foreach ($bookings_by_service as $index => $service): 
                $color = $colors[$index % count($colors)];
                $percentage = $total > 0 ? ($service['booking_count'] / $total) * 100 : 0;
                $degrees = $percentage * 3.6;
                
                if ($index < count($bookings_by_service) - 1) {
                    $gradient .= "{$color} {$total_rotation}deg " . ($total_rotation + $degrees) . "deg, ";
                    $total_rotation += $degrees;
                } else {
                    $gradient .= "{$color} {$total_rotation}deg 360deg";
                }
            endforeach;
            ?>
            <div class="ctrlbs-pie-chart" style="background: conic-gradient(<?php echo esc_attr($gradient); ?>);">
            </div>
            <div class="ctrlbs-pie-legend">
                <?php foreach ($bookings_by_service as $index => $service): ?>
                    <div class="ctrlbs-legend-item">
                        <span class="ctrlbs-legend-color" style="background: <?php echo esc_attr($colors[$index % count($colors)]); ?>"></span>
                        <span class="ctrlbs-legend-label"><?php echo esc_html($service['service_name']); ?></span>
                        <span class="ctrlbs-legend-value">(<?php echo esc_html($service['booking_count']); ?>)</span>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>
</div>
